phonebookui/Phonebook2/ccapplication/ccacommlauncherplugin/src/ccappcommlauncherheadercontrol.cpp
branchRCL_3
changeset 85 38bb213f60ba
parent 68 9da50d567e3c
--- a/phonebookui/Phonebook2/ccapplication/ccacommlauncherplugin/src/ccappcommlauncherheadercontrol.cpp	Wed Sep 15 11:56:55 2010 +0300
+++ b/phonebookui/Phonebook2/ccapplication/ccacommlauncherplugin/src/ccappcommlauncherheadercontrol.cpp	Wed Oct 13 14:15:33 2010 +0300
@@ -459,15 +459,15 @@
         case TPointerEvent::EButton1Down:
             {
             TCmsContactStore cntStore = iPlugin.ContactHandler().ContactStore();
-            // Image selection popup            
-               // Image selection popup should not be shown for contact's that belong to sdn store / Sim Store
-               // Image selection popup can be shown for the contact that belongs to
-               //      local contact DB / XSP Store           
-    
-            if( ( (cntStore != ECmsContactStoreSdn) && (cntStore != ECmsContactStoreSim) )                                 
-                           &&
-                           iImage->Rect().Contains(aPointerEvent.iPosition)
-                         )                
+            // Image selection popup
+            // Image selection popup should not be shown for contact's that belong to sdn store
+            // Image selection popup can be shown only if the default 
+            //      saving memory includes local contact db (contacts.cdb) or if the contact belongs to
+            //      local contact DB            
+            if( cntStore != ECmsContactStoreSdn 
+                && IsPhoneMemoryInConfigurationL()
+                     && (cntStore != ECmsContactStoreSim)
+                && iImage->Rect().Contains(aPointerEvent.iPosition) )
                 {
                 // Show the feedback
                 MTouchFeedback* feedback = MTouchFeedback::Instance();